@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2016-10-29'; # DATE
-our $VERSION = '1.44'; # VERSION
+our $DATE = '2017-01-04'; # DATE
+our $VERSION = '1.45'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -61,13 +61,15 @@ _
         schema => 'str*',
     },
     gen_args => {
-        summary => 'Arguments to be passed to `Perinci::CmdLine->new()`',
+        summary => 'Arguments to be passed to '.
+            '`Perinci::CmdLine::Gen::gen_pericmd_script()`',
         schema => 'hash*',
         req => 1,
+        tags => ['category:input'],
     },
     inline_gen_args => {
         summary => 'Additional arguments to be passed to '.
-            '`Perinci::CmdLine::Inline->new()`',
+            '`Perinci::CmdLine::Gen::gen_pericmd_script()`',
         description => <<'_',
 
 Keys from this argument will be added to `gen_args` and will only be used when
@@ -75,10 +77,11 @@ Keys from this argument will be added to `gen_args` and will only be used when
 
 _
         schema => 'hash*',
+        tags => ['category:input', 'variant:inline'],
     },
     classic_gen_args => {
         summary => 'Additional arguments to be passed to '.
-            '`Perinci::CmdLine::Classic->new()`',
+            '`Perinci::CmdLine::Gen::gen_pericmd_script()`',
         description => <<'_',
 
 Keys from this argument will be added to `gen_args` and will only be used when
@@ -86,10 +89,11 @@ Keys from this argument will be added to `gen_args` and will only be used when
 
 _
         schema => 'hash*',
+        tags => ['category:input', 'variant:classic'],
     },
     lite_gen_args => {
         summary => 'Additional arguments to be passed to '.
-            '`Perinci::CmdLine::Lite->new()`',
+            '`Perinci::CmdLine::Gen::gen_pericmd_script()`',
         description => <<'_',
 
 Keys from this argument will be added to `gen_args` and will only be used when
@@ -97,20 +101,24 @@ Keys from this argument will be added to `gen_args` and will only be used when
 
 _
         schema => 'hash*',
+        tags => ['category:input', 'variant:lite'],
     },
     argv => {
         summary => 'Command-line arguments that will be passed to '.
             'generated CLI script',
         schema => 'array*',
         default => [],
+        tags => ['category:input'],
     },
     stdin => {
         summary => "Supply stdin content to generated CLI script",
         schema => 'str*',
+        tags => ['category:input'],
     },
     env => {
         summary => "Set environment variables for generated CLI script",
         schema => 'hash*',
+        tags => ['category:input'],
     },
     comp_line0 => {
         summary => "Set COMP_LINE environment for generated CLI script",
@@ -122,6 +130,7 @@ Can contain `^` (caret) character which will be stripped from the final
 
 _
         schema => 'str*',
+        tags => ['category:input'],
     },
     inline_allow => {
         summary => "Modules to allow to be loaded when testing generated ".
@@ -137,12 +146,40 @@ This means the script will only be able to load core modules. But if the script
 is allowed to load additional modules, you can set this `inline_allow` parameter
 to, e.g. `["Foo::Bar","Baz"]` and the above perl option will become:
 
-    -Mlib::filter=allow_noncore,0,allow=Foo::Bar;Baz
+    -Mlib::filter=allow_noncore,0,allow,Foo::Bar;Baz
+
+To skip using this option, set `inline_run_filter` to false.
 
 _
         schema => ['array*', of=>'perl::modname*'],
+        tags => ['category:input', 'variant:inline'],
+    },
+    inline_run_filter => {
+        summary => "Whether to use -Mfilter when running generated ".
+            "Perinci::CmdLine::Inline script",
+        schema => ['bool*'],
+        default => 1,
+        description => <<'_',
+
+By default, when running the generated Perinci::CmdLine::Inline script, this
+perl option will be used (see <pm:lib::filter> for more details):
+
+    -Mlib::filter=allow_noncore,0,...
+
+This is to test that the script does not require non-core modules. To skip using
+this option (e.g. when using `pack_deps` gen option set to false), set
+this option to false.
+
+_
+        tags => ['category:input', 'variant:inline'],
     },
 
+    gen_status => {
+        summary => 'Expected generate result status',
+        schema  => 'int*',
+        default => 200,
+        tags => ['category:assert'],
+    },
     exit_code => {
         summary => "Expected script's exit code",
         schema => 'int*',
@@ -304,6 +341,11 @@ sub pericmd_run_test_groups_ok {
             $gen_args{output_file} = $filename;
             $gen_args{overwrite} = 1;
             my $gen_res = gen_pericmd_script(%gen_args);
+            if (exists $test_args{gen_status}) {
+                is($gen_res->[0], $test_args{gen_status}, "gen status")
+                    or return;
+                return if $test_args{gen_status} != 200;
+            }
             die "Can't generate CLI script at $filename: ".
                 "$gen_res->[0] - $gen_res->[1]" unless $gen_res->[0] == 200;
             note "Generated CLI script at $filename";
@@ -318,9 +360,9 @@ sub pericmd_run_test_groups_ok {
                  capture_stdout=>\$stdout, capture_stderr=>\$stderr, lang=>'C'},
                 $^X,
                 # pericmd-inline script must work with only core modules
-                ($class eq 'Perinci::CmdLine::Inline' ?
+                ($class eq 'Perinci::CmdLine::Inline' && ($test_args{inline_run_filter} // 1) ?
                      ("-Mlib::filter=allow_noncore,0".
-                      ($test_args{inline_allow} ? ",allow=".
+                      ($test_args{inline_allow} ? ",allow,".
                        join(";",@{$test_args{inline_allow}}) : "")) : ()),
                 $filename,
                 @{ $test_args{argv} // []},
@@ -501,6 +543,9 @@ $SPEC{pericmd_run_tests_ok} = {
     summary => 'Run a group of tests of a Perinci::CmdLine script',
     args => {
         %common_args,
+        name => {
+            schema => 'str*',
+        },
         tests => {
             schema => ['array*', of=>'hash*'],
             req => 1,
@@ -516,7 +561,7 @@ sub pericmd_run_tests_ok {
 
     {
         my $group = {
-            name => 'single group (pericmd_run_tests_ok)',
+            name => delete($args{name}) // 'single group (pericmd_run_tests_ok)',
         };
         if (grep {$_->{comp_answer}} @{ $args{tests} }) {
             $group->{completion_tests} = delete $args{tests};
@@ -1747,7 +1792,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.44 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-10-29.
+This document describes version 1.45 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2017-01-04.
 
 =for Pod::Coverage ^(pericmd_ok)$
 
@@ -1774,7 +1819,7 @@ Which Perinci::CmdLine class are we testing.
 
 =item * B<classic_gen_args> => I<hash>
 
-Additional arguments to be passed to `Perinci::CmdLine::Classic->new()`.
+Additional arguments to be passed to `Perinci::CmdLine::Gen::gen_pericmd_script()`.
 
 Keys from this argument will be added to C<gen_args> and will only be used when
 C<class> is C<Perinci::CmdLine::Classic>.
@@ -1805,7 +1850,11 @@ Expected script's exit code (as regex pattern).
 
 =item * B<gen_args>* => I<hash>
 
-Arguments to be passed to `Perinci::CmdLine->new()`.
+Arguments to be passed to `Perinci::CmdLine::Gen::gen_pericmd_script()`.
+
+=item * B<gen_status> => I<int> (default: 200)
+
+Expected generate result status.
 
 =item * B<inline_allow> => I<array[perl::modname]>
 
@@ -1820,18 +1869,33 @@ This means the script will only be able to load core modules. But if the script
 is allowed to load additional modules, you can set this C<inline_allow> parameter
 to, e.g. C<["Foo::Bar","Baz"]> and the above perl option will become:
 
- -Mlib::filter=allow_noncore,0,allow=Foo::Bar;Baz
+ -Mlib::filter=allow_noncore,0,allow,Foo::Bar;Baz
+
+To skip using this option, set C<inline_run_filter> to false.
 
 =item * B<inline_gen_args> => I<hash>
 
-Additional arguments to be passed to `Perinci::CmdLine::Inline->new()`.
+Additional arguments to be passed to `Perinci::CmdLine::Gen::gen_pericmd_script()`.
 
 Keys from this argument will be added to C<gen_args> and will only be used when
 C<class> is C<Perinci::CmdLine::Inline>.
 
+=item * B<inline_run_filter> => I<bool> (default: 1)
+
+Whether to use -Mfilter when running generated Perinci::CmdLine::Inline script.
+
+By default, when running the generated Perinci::CmdLine::Inline script, this
+perl option will be used (see L<lib::filter> for more details):
+
+ -Mlib::filter=allow_noncore,0,...
+
+This is to test that the script does not require non-core modules. To skip using
+this option (e.g. when using C<pack_deps> gen option set to false), set
+this option to false.
+
 =item * B<lite_gen_args> => I<hash>
 
-Additional arguments to be passed to `Perinci::CmdLine::Lite->new()`.
+Additional arguments to be passed to `Perinci::CmdLine::Gen::gen_pericmd_script()`.
 
 Keys from this argument will be added to C<gen_args> and will only be used when
 C<class> is C<Perinci::CmdLine::Lite>.
@@ -1965,6 +2029,8 @@ Arguments ('*' denotes required arguments):
 
 Which Perinci::CmdLine class are we testing.
 
+=item * B<name> => I<str>
+
 =item * B<tests>* => I<array[hash]>
 
 =back
@@ -2022,7 +2088,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
